(() => {
    const config = {
        maxLength: 150,
        includeSourceLink: true,
        sourcePrefix: 'Източник: ', 
        sourceSuffix: '',
        translitChars: {
            'ABEMKHO\u03A0PCTXae\u0138opcyxIiJjSs': 
            '\u0410\u0412\u0415\u041C\u041A\u041D\u041E\u041F\u0420\u0421\u0422\u0425\u0430\u0435\u043A\u043E\u0440\u0441\u0443\u0445\u0406\u0456\u0408\u0458\u0405\u0455'
        }
    };

    function generateShortUrl(fullUrl) {
        try {
            const url = new URL(fullUrl);
            const path = url.pathname.split('/').pop();
            const cleanPath = path
                .normalize('NFD')
                .replace(/[\u0300-\u036f]/g, '')
                .replace(/[^\w\s-]/g, '')
                .replace(/\s+/g, '-')
                .toLowerCase()
                .slice(0, 30);
            
            return `${url.hostname}/${cleanPath}`;
        } catch {
            return fullUrl;
        }
    }

    function transliterateText(text) {
        const translitMap = new Map();
        
        Object.keys(config.translitChars).forEach((source, index) => {
            const target = config.translitChars[source];
            for (let i = 0; i < source.length; i++) {
                translitMap.set(source[i], target[i]);
                translitMap.set(target[i], source[i]);
            }
        });

        return text.split('').map(char => 
            translitMap.get(char) || char
        ).join('');
    }

    function isCodeLikeText(text) {
        const codePatterns = [
            /<[^>]+>/,
            /\{[^}]+\}/,
            /\/\/.+/,
            /\/\*.+\*\//,
            /--\s.+/
        ];

        return codePatterns.some(pattern => pattern.test(text));
    }

    function handleCopyEvent(event) {
    const selectedText = window.getSelection().toString();
    
    if (selectedText.length <= config.maxLength) {
        // Директно копира оригиналния текст без обработка
        return;
    }

    if (!isCodeLikeText(selectedText)) {
        let processedText = transliterateText(selectedText);
        
        if (config.includeSourceLink) {
            const shortUrl = generateShortUrl(window.location.href);
            processedText += `\n\n${config.sourcePrefix}${shortUrl}${config.sourceSuffix}`;
        }
        if (event.clipboardData) {
            event.clipboardData.setData('text/plain', processedText);
            event.preventDefault();
        }
    }
}

    document.addEventListener('copy', handleCopyEvent, false);
})();